@@ -9,7 +9,10 @@ class AddMode(str, Enum):
 
 
 def get_expanded_out_root(
-    out_root: Path, project_root: Path, add_mode: AddMode
+    out_root: Path,
+    project_root: Path,
+    render_relative_root_in_output: Path,
+    add_mode: AddMode,
 ) -> Path:
     if add_mode == AddMode.USER:
         # Always use full absolute paths for user
@@ -18,6 +21,7 @@ def get_expanded_out_root(
         # Return a project-relative path for project
         return out_root.absolute().relative_to(project_root.absolute())
     if add_mode == AddMode.LOCAL:
-        # Local out path is always .
-        return Path(".")
+        # Needs to be the relative path to get back to template root from the
+        # render relative root
+        return Path(*[".." for _ in range(len(render_relative_root_in_output.parts))])
     raise ValueError(f"unsupported add mode {add_mode}")
